@@ -6,16 +6,6 @@ use XML::Simple;
 use Getopt::Long;
 use Pod::Usage;
 
-# use Data::Dumper;
-
-#   print Dumper($config);
-
-# my $xs_obj = XML::Simple->new();
-
-# my $xs_obj_out = XML::Simple->new();
-
-# my $ref_XS_files = $xs_obj->XMLin($ARGV[0]);
-
 my $doc_id;
 my $text;
 my $i;
@@ -34,8 +24,6 @@ if (scalar(@ARGV) ==0) {
 
 Getopt::Long::Configure ("bundling");
 
-# 	   'verbose|v:i'    => \$verbose,
-
 GetOptions('help|?'       => \$help,
 	   'man'          => \$man,
 	   'file|f=s'     => \$filename,
@@ -57,7 +45,6 @@ $text[0] =~ s/﻿//;
 my @initial_text = @text;
 
 binmode(stdout,":utf8");
-# binmode(stdin,":latin9");
 
 map {
     $_ =~ s/&amp;/&/go;
@@ -84,22 +71,8 @@ exit;
 
 my $initial_text;
 
-# my $initial_text = join('', @text);
-
-# $initial_text =~ s/&amp;/&/go;
-# $initial_text =~ s/&quot;/\"/og;
-# $initial_text =~ s/&apos;/\'/og;
-# $initial_text =~ s/&lt;/</og;
-# $initial_text =~ s/&gt;/>/og;
-
-# push @doc_initial_text, $initial_text;
-
 close FILE;
 
-# my @text_with_sections_and_items_step2;
-
-# my @modified_sections;
-
 print '<?xml version="1.0" encoding="UTF-8"?>' . "\n";
 print '<documentCollection xmlns="http://alvis.info/enriched/" version="1.1">'. "\n";
 
@@ -115,27 +88,18 @@ foreach $initial_text (@doc_initial_text) {
 
     my @text_with_sections = &identify_sections($initial_text);
 
-#     exit;
-    
     my @text_with_sections_and_items;
     my $section_nb = 0;
     my @text_section;
 
     foreach $section (@text_with_sections) {
-# 	warn "****" . $section->{"content"} . "\n";
 	push @text_with_sections_and_items, &identify_listitems($section->{"content"}, \$section_nb);
     }
 
-#     foreach $section (@text_with_sections_and_items) {
-# 	warn "****" . $section->{"content"} . "\n";
-#     }
     $documents{$doc_id} = \@text_with_sections_and_items;
-
     $max_doc_id = $doc_id;
 }
 
-
-
 foreach $doc_id (sort {$a <=> $b} keys  %documents) {
     warn "Processing document $doc_id / $max_doc_id (title identification second step)\n";
     
@@ -143,36 +107,18 @@ foreach $doc_id (sort {$a <=> $b} keys  %documents) {
 
     foreach $section (@text_with_sections_and_items) {
 	if ($title = &identify_title($section->{"content"}, \%titles)) {
-# 	    print STDERR "title=" . $title . "\n";
 	    $section->{"title"} = $title;
 	}
     }
 
-# A dÃ©commenter pour la deuxiÃ¨me passe
-#     my @text_with_sections_and_items_step2;
-#     foreach $section (@text_with_sections_and_items) {
-# 	@modified_sections = &identify_title_from_known_titles($section, \%titles);
-# 	if (scalar(@modified_sections)) {
-# 	    push @text_with_sections_and_items_step2, @modified_sections;
-# 	} else {
-# 	    push @text_with_sections_and_items_step2, $section;
-# 	}
-#     }
-#     &print_documentRecord($doc_id, \@text_with_sections_and_items_step2);
-
-# A commenter pour la deuxiÃ¨me passe
-#    &print_documentRecord($doc_id, \@text_with_sections_and_items_step);
     &print_documentRecord($doc_id, $filename, \@text_with_sections_and_items, $lang);
 }
 
-# my $xml = $xs->XMLout($hashref [, <options>]);
-
 print '</documentCollection>' . "\n";
 
 sub new_section {
     my ($ref_section_nb, $ref_text_with_sections, $text, $sectionType) = @_;
     
-
     $sectionType = "narrative" unless $sectionType;
     $$ref_section_nb++;
     
@@ -183,7 +129,6 @@ sub new_section {
 
 sub add_in_section {
     my ($section_nb, $ref_text_with_sections, $text) = @_;
-    # "\n" . 
 
     if (ref($ref_text_with_sections->[$section_nb]->{"content"}) eq "ARRAY") {
 	push @{$ref_text_with_sections->[$section_nb]->{"content"}}, $text;
@@ -197,13 +142,11 @@ sub new_item {
     
     $$ref_item_nb++;
     $ref_text_with_items->[$$ref_item_nb] = $text;
-
 }
 
 sub add_in_item {
     my ($item_nb, $ref_text_with_items, $text) = @_;
     
-# "\n" . 
     $ref_text_with_items->[$item_nb] .= $text;
 }
 
@@ -211,11 +154,9 @@ sub print_list {
     my ($list_ref, $title) = @_;
     my $item;
 
-     # warn "$list_ref\n";
     my $item_str = "";
     foreach $item (@{$list_ref}) {
 	if ($item ne "") {
-# 	warn "Here $item\n";
 	    $item_str .=  XMLout($item, "RootName" => "item",
 				 'NoIndent' => 1,
 		);
@@ -230,8 +171,6 @@ sub print_list {
 	print $item_str;
 	print "</list></section>\n";
     }
-
-    
 }
 
 sub print_documentRecord {
@@ -304,21 +243,12 @@ sub identify_sections {
     my $texttmp;
     my @text = split /\n/, $text;
 
-#     warn "Size: " . scalar(@text);
-
-     map {$_ .= "\n"} @text;
-
-#     for($i=0;$i < scalar(@text); $i++) {
-# 	$text[$i] .= "\n";
-#     }
+    map {$_ .= "\n"} @text;
 
     my @text_with_sections;
     my $section_nb = 0;
     $i = 0;
 
-#       warn ">" . $text[$i];
-#     do {
-#	if ($text[$i] !~ /^\s*$/o) {
     &new_section(\$section_nb, \@text_with_sections, $text[$i]);
 
     my @tmp = split /\t/, $text[$i];
@@ -329,172 +259,39 @@ sub identify_sections {
 	&add_section_in_section(\$section_nb, \@text_with_sections, $sub_sections[$sub_section_nb]);
     }
 
-#     warn "==>($section_nb)" . $text_with_sections[$section_nb]->{"content"};
-#	}
     $i++;
     do {
-#       warn "->" . $text[$i];
 	&add_in_section($section_nb, \@text_with_sections, $text[$i]);
-#  	warn "==>($section_nb)" . $text_with_sections[$section_nb]->{"content"};
 	$i++;
     } while($text[$i] =~ /^\s*\n$/);
-#    $i--;
     $section_nb++;
     for(;$i <= $#text; $i++) {
-#  	warn "i: $i\n";	
-#   	warn "-->" . $text[$i];
 
 	if (($text[$i] =~ /^\s*[^a-z\d]+:/o) || ($text[$i] =~ /^\s*[^a-z\d][^:]+:/o) || (index($text[$i], "******") > -1)){
 	    &new_section(\$section_nb, \@text_with_sections, $text[$i]);
-#  	    warn "==>($section_nb)" . $text_with_sections[$section_nb]->{"content"};
 	    next;
 	}
-# 	if (($text[$i] =~ /^\s*[^a-z\d\(]+/o) && ($text[$i - 1] !~ /[a-z,]\s*$/o)){
-# 	    &new_section(\$section_nb, \@text_with_sections, $text[$i]);
-# 	    next;
-# 	}
 	&add_in_section($section_nb, \@text_with_sections, $text[$i]);
-#  	warn "==>($section_nb)" . $text_with_sections[$section_nb]->{"content"};
     }
     return(@text_with_sections);
 }
 
 sub add_section_in_section {
     my ($section_nb, $ref_text_with_sections, $text) = @_;
-    # "\n" . 
 
-
-#     warn "add\n";
     if (ref($ref_text_with_sections->[$section_nb]->{"content"}) eq "ARRAY") {
 	my %tmp = ("content" => $text);
 	push @{$ref_text_with_sections->[$section_nb]->{"content"}}, \%tmp;
-# 	push @{$ref_text_with_sections->[$section_nb]->{"content"}}, $text;
     } else {
 	$ref_text_with_sections->[$section_nb]->{"content"} .= $text;
     }
 }
 
-
-# sub identify_listitems {
-#     my ($section, $section_nb_ref) = @_;
-#     my @text_with_sections_and_items;
-
-#     my $item_regex = '^\d+\.\s+';
-
-# #      warn "->$section";
-
-#     my @listSection = (
-# 	"DISCHARGE MEDICATIONS",
-# 	"MEDICATIONS ON ADMISSION",
-# 	"ADMISSION MEDICATIONS",
-# 	"ADDENDUM TO MEDICATIONS ON DISCHARGE",
-# 	"MEDICATION AT TIME OF DISCHARGE",
-# # 	"",
-# # 	"",
-# # 	"",
-# # 	"",
-# 	);
-
-
-# }
-
-# sub add_in_section {
-#     my ($section_nb, $ref_text_with_sections, $text) = @_;
-#     # "\n" . 
-
-#     $ref_text_with_sections->[$section_nb]->{"content"} .= $text;
-# }
-
-# sub new_item {
-#     my ($ref_item_nb, $ref_text_with_items, $text) = @_;
-    
-#     $$ref_item_nb++;
-#     $ref_text_with_items->[$$ref_item_nb] = $text;
-
-# }
-
-# sub add_in_item {
-#     my ($item_nb, $ref_text_with_items, $text) = @_;
-    
-# # "\n" . 
-#     $ref_text_with_items->[$item_nb] .= $text;
-# }
-
-# sub print_list {
-#     my ($list_ref) = @_;
-#     my $item;
-
-#     print "<section><list>";
-#     foreach $item (@{$list_ref}) {
-# 	print XMLout($item, "RootName" => "item",
-# 		     'NoIndent' => 1,
-# 	    );
-#     }
-#     print "</list></section>";
-
-    
-# }
-
-
-# sub identify_sections {
-#     my ($text) = @_;
-
-#     my @text = split /\n/, $text;
-
-# #     warn "Size: " . scalar(@text);
-
-#      map {$_ .= "\n"} @text;
-
-# #     for($i=0;$i < scalar(@text); $i++) {
-# # 	$text[$i] .= "\n";
-# #     }
-
-#     my @text_with_sections;
-#     my $section_nb = 0;
-#     $i = 0;
-
-# #      warn "-->" . $text[$i];
-# #     do {
-# #	if ($text[$i] !~ /^\s*$/o) {
-#     &new_section(\$section_nb, \@text_with_sections, $text[$i]);
-# #     warn "==>($section_nb)" . $text_with_sections[$section_nb]->{"content"};
-# #	}
-#     $i++;
-#     do {
-# 	&add_in_section($section_nb, \@text_with_sections, $text[$i]);
-# #  	warn "==>($section_nb)" . $text_with_sections[$section_nb]->{"content"};
-# 	$i++;
-#     } while($text[$i] =~ /^\s*\n$/);
-# #    $i--;
-#     $section_nb++;
-#     for(;$i <= $#text; $i++) {
-# # 	warn "i: $i\n";	
-# #  	warn "-->" . $text[$i];
-
-# 	if (($text[$i] =~ /^\s*[^a-z\d]+:/o) || ($text[$i] =~ /^\s*[^a-z\d][^:]+:/o) || (index($text[$i], "******") > -1)){
-# 	    &new_section(\$section_nb, \@text_with_sections, $text[$i]);
-# #  	    warn "==>($section_nb)" . $text_with_sections[$section_nb]->{"content"};
-# 	    next;
-# 	}
-# # 	if (($text[$i] =~ /^\s*[^a-z\d\(]+/o) && ($text[$i - 1] !~ /[a-z,]\s*$/o)){
-# # 	    &new_section(\$section_nb, \@text_with_sections, $text[$i]);
-# # 	    next;
-# # 	}
-# 	&add_in_section($section_nb, \@text_with_sections, $text[$i]);
-# #  	warn "==>($section_nb)" . $text_with_sections[$section_nb]->{"content"};
-#     }
-#     return(@text_with_sections);
-# }
-
-
 sub identify_listitems {
     my ($section, $section_nb_ref) = @_;
     my @text_with_sections_and_items;
 
     my $item_regex = '^\b\d+\.\s+';
-
-#          warn "-> () $section";
-
     my @listSection = (
 	"DISCHARGE MEDICATIONS",
 	"DISCHARGE MEDS",
@@ -583,7 +380,6 @@ sub identify_listitems {
 	    $text_with_sections_and_items[$$section_nb_ref]->{"title"} = $start_listsection_title;
 
 	    $sectionType = "list";
-#	    warn "--> ".  $start_listsection . "\n";
 
 	    &new_item(\$item_nb, \@items, ""); 
 #      	&add_in_section($$section_nb_ref, \@text_with_sections_and_items, \@items);
@@ -593,32 +389,24 @@ sub identify_listitems {
 
 	    push @sections, \%tmp2;
 	}
-# 	warn "$section: it is not a list\n";
     }
-#      warn "type of section: $sectionType\n";
 
     @text_section = split /\n/, $section;
 
     map{$_ .= "\n"} @text_section;
 
     for($j=0;$j<= $#text_section;$j++) {
-#    	warn "=====> " . $text_section[$j]  . "\n";
 	if ($text_section[$j] =~ /$item_regex/) {
-#       	    warn "match item $item_nb $& $sectionType\n";
 	    if (($item_nb == -1) && ($sectionType ne "list")) {
 		my $title;
 		my @sections;
-#   		warn "==>" . $text_section[$j] . "\n";
 		if ($text_section[$j] =~ /^(\s*([A-Z][^:\d\+\.]+):\s*)/o) {
-#  		    warn "TITLE = $1 ($&)\n";
 		    $title = $2;
 		    $sectionType = "list";
 		    my %tmp = ("content" => $1,
 # 		   "title" => $listSection[$k],
 			);
 		    &new_item(\$item_nb, \@items, $');  # ' }
-
-	
 		    push @sections, \%tmp;
 		    &new_section($section_nb_ref, \@text_with_sections_and_items, \@sections, $sectionType);
 		    $text_with_sections_and_items[$$section_nb_ref]->{"title"} = $title;
@@ -630,7 +418,6 @@ sub identify_listitems {
 		    push @sections, \%tmp2;
 		    
 		} else {
-#		    warn "Pass here\n";
 		    &add_in_section($$section_nb_ref, \@text_with_sections_and_items, $text_section[$j]);
 		}
 
@@ -642,17 +429,13 @@ sub identify_listitems {
 	    next;
 	}
 	if ($item_nb == -1) {
-#  	    warn "add in item -1\n";
 	    &add_in_section($$section_nb_ref, \@text_with_sections_and_items, $text_section[$j]);
-#  	    warn "==>($$section_nb_ref)" . $text_with_sections_and_items[$$section_nb_ref]->{"content"};
 	} else {
-#  	    warn "add in item\n";
 	    &add_in_item($item_nb, \@items, $text_section[$j]);
 	}
     }
     if (defined $section_tail) {
 	&add_in_section($$section_nb_ref, \@text_with_sections_and_items, $section_tail);
-# 	    warn "==>($$section_nb_ref)" . $text_with_sections_and_items[$$section_nb_ref]->{"content"};
     }
     $$section_nb_ref++;
     return(@text_with_sections_and_items);
@@ -660,7 +443,6 @@ sub identify_listitems {
 
 sub identify_title  {
     my ($text, $titles_ref) = @_;
-# 	print STDERR "==>$text\n";
     my $title = "";
 
     if (($text ne "") && (ref($text) ne "ARRAY")) {
@@ -679,16 +461,6 @@ sub identify_title  {
 		}
 	    }
 	}
-
-
-
-# 	    if (|([A-Z+\- ]+)[:\.]
-# 	}
-# 	    if ($text =~ /(^([A-Z\-]{2,}(\s[A-Z\-]+)+)\b)/) {
-# 		$title = $1;
-# 		print STDERR ">>>title2 = $title\n";
-# 	    }
-# 	}
     }
     return($title);
 }
@@ -712,7 +484,6 @@ sub identify_title_from_known_titles {
 	    if (index($text, $known_title, 1) != -1) {
 		if ($text =~ s/(\b)(\Q$known_title\E\b)/\1<SECTION>\2<TITLE>\2/) {
 		    $exists_title++;
-# 		    print STDERR "found $known_title in $text\n\n";
 		}
 	    }
 	}
@@ -727,15 +498,10 @@ sub identify_title_from_known_titles {
 		$end_title_pos = index($sections_text[$i], "<TITLE>",0);
 		$title = substr($sections_text[$i], 0, $end_title_pos);
 		$new_text = substr($sections_text[$i], $end_title_pos+7);
-
-# 		print STDERR "title=$title\n";
-# 		print STDERR "content=$new_text\n";
 		$sections[$i] = {"content" => $new_text,
 				 "title" => $title,
 			     };
-	
 	    }
-	    
 	}
     }
     return(@sections);
@@ -743,14 +509,15 @@ sub identify_title_from_known_titles {
 
 ########################################################################
 
+=encoding utf8
+
 =head1 NAME
 
-Txt2Ogmios.pl - Script for converting text file in XML Ogmios file
-
+Txt2Ogmios-TabularFiles.pl - Script for converting tabular files in XML Ogmios files
 
 =head1 SYNOPSIS
 
-Txt2Ogmios.pl [option] --file <filename> --lang <language> --docId <documentId>
+Txt2Ogmios-TabularFiles.pl [option] --file <filename> --lang <language> --docId <documentId>
 
 where option can be --help --man
 
@@ -760,7 +527,7 @@ where option can be --help --man
 
 =item --file <filename>
 
-The switch sets the input text file (to convert).
+The switch sets the input tabular file (to convert).
 
 =item --lang <language>
 
@@ -783,9 +550,11 @@ print man page of grepTerms.pl
 
 =head1 DESCRIPTION
 
-This script converts a text file as input (switch C<file>) into a XML
-Omgios file. The language property field is set with the switch
-C<lang>, and the document identifier is set with the switch C<dociI>.
+This script converts a tabular file as input (switch C<file>) into a XML
+Omgios file. It is assumed that some columns contain free text.
+
+The language property field is set with the switch C<lang>, and the
+document identifier is set with the switch C<dociI>.
 
 =head1 SEE ALSO
 
