@@ -3,19 +3,12 @@
 use strict;
 use XML::Simple;
 
+use utf8;
+use open qw(:utf8 :std);
+
 use Getopt::Long;
 use Pod::Usage;
 
-# use Data::Dumper;
-
-#   print Dumper($config);
-
-# my $xs_obj = XML::Simple->new();
-
-# my $xs_obj_out = XML::Simple->new();
-
-# my $ref_XS_files = $xs_obj->XMLin($ARGV[0]);
-
 my $doc_id;
 my $text;
 my $i;
@@ -34,8 +27,6 @@ if (scalar(@ARGV) ==0) {
 
 Getopt::Long::Configure ("bundling");
 
-# 	   'verbose|v:i'    => \$verbose,
-
 GetOptions('help|?'       => \$help,
 	   'man'          => \$man,
 	   'file|f=s'     => \$filename,
@@ -46,35 +37,26 @@ GetOptions('help|?'       => \$help,
 pod2usage(1) if $help;
 pod2usage(-exitstatus => 0, -verbose => 2) if $man;
 
-
-
 my @doc_initial_text;
 
-open FILE, "<:utf8", $filename;
-my @text = <FILE>;
+my $fh = *STDIN;
+if (defined $filename) {
+    open $fh, "<:utf8", $filename;
+}
+my @text = <$fh>;
+
+if (defined $filename) {
+    close FILE;
+}
+
 $text[0] =~ s/﻿//;
 
 my @initial_text = @text;
 
 binmode(stdout,":utf8");
-# binmode(stdin,":latin9");
-
-# map {
-#     $_ =~ s/&amp;/&/go;
-#     $_ =~ s/&quot;/\"/og;
-#     $_ =~ s/&apos;/\'/og;
-#     $_ =~ s/&lt;/</og;
-#     $_ =~ s/&gt;/>/og;
-#     $_ =~ s/\x{0009}/        /og;
-#     $_ =~ s/[\x{0000}-\x{001F}]//og;
-#     chomp;
-# } @initial_text;
-
 
 map { $_ = &cleanOUTPUT($_); } @initial_text;
 
-
-
 my @text_with_sections;
 my $line;
 
@@ -93,22 +75,6 @@ exit;
 
 my $initial_text;
 
-# my $initial_text = join('', @text);
-
-# $initial_text =~ s/&amp;/&/go;
-# $initial_text =~ s/&quot;/\"/og;
-# $initial_text =~ s/&apos;/\'/og;
-# $initial_text =~ s/&lt;/</og;
-# $initial_text =~ s/&gt;/>/og;
-
-# push @doc_initial_text, $initial_text;
-
-close FILE;
-
-# my @text_with_sections_and_items_step2;
-
-# my @modified_sections;
-
 print '<?xml version="1.0" encoding="UTF-8"?>' . "\n";
 print '<documentCollection xmlns="http://alvis.info/enriched/" version="1.1">'. "\n";
 
@@ -123,28 +89,18 @@ foreach $initial_text (@doc_initial_text) {
     warn "Processing document \n";
 
     my @text_with_sections = &identify_sections($initial_text);
-
-#     exit;
     
     my @text_with_sections_and_items;
     my $section_nb = 0;
     my @text_section;
 
     foreach $section (@text_with_sections) {
-# 	warn "****" . $section->{"content"} . "\n";
 	push @text_with_sections_and_items, &identify_listitems($section->{"content"}, \$section_nb);
     }
-
-#     foreach $section (@text_with_sections_and_items) {
-# 	warn "****" . $section->{"content"} . "\n";
-#     }
     $documents{$doc_id} = \@text_with_sections_and_items;
-
     $max_doc_id = $doc_id;
 }
 
-
-
 foreach $doc_id (sort {$a <=> $b} keys  %documents) {
     warn "Processing document $doc_id / $max_doc_id (title identification second step)\n";
     
@@ -152,30 +108,13 @@ foreach $doc_id (sort {$a <=> $b} keys  %documents) {
 
     foreach $section (@text_with_sections_and_items) {
 	if ($title = &identify_title($section->{"content"}, \%titles)) {
-# 	    print STDERR "title=" . $title . "\n";
 	    $section->{"title"} = $title;
 	}
     }
 
-# A dÃ©commenter pour la deuxiÃ¨me passe
-#     my @text_with_sections_and_items_step2;
-#     foreach $section (@text_with_sections_and_items) {
-# 	@modified_sections = &identify_title_from_known_titles($section, \%titles);
-# 	if (scalar(@modified_sections)) {
-# 	    push @text_with_sections_and_items_step2, @modified_sections;
-# 	} else {
-# 	    push @text_with_sections_and_items_step2, $section;
-# 	}
-#     }
-#     &print_documentRecord($doc_id, \@text_with_sections_and_items_step2);
-
-# A commenter pour la deuxiÃ¨me passe
-#    &print_documentRecord($doc_id, \@text_with_sections_and_items_step);
     &print_documentRecord($doc_id, $filename, \@text_with_sections_and_items, $lang);
 }
 
-# my $xml = $xs->XMLout($hashref [, <options>]);
-
 print '</documentCollection>' . "\n";
 
 sub new_section {
@@ -192,7 +131,6 @@ sub new_section {
 
 sub add_in_section {
     my ($section_nb, $ref_text_with_sections, $text) = @_;
-    # "\n" . 
 
     if (ref($ref_text_with_sections->[$section_nb]->{"content"}) eq "ARRAY") {
 	push @{$ref_text_with_sections->[$section_nb]->{"content"}}, $text;
@@ -212,7 +150,6 @@ sub new_item {
 sub add_in_item {
     my ($item_nb, $ref_text_with_items, $text) = @_;
     
-# "\n" . 
     $ref_text_with_items->[$item_nb] .= $text;
 }
 
@@ -220,11 +157,9 @@ sub print_list {
     my ($list_ref, $title) = @_;
     my $item;
 
-     # warn "$list_ref\n";
     my $item_str = "";
     foreach $item (@{$list_ref}) {
 	if ($item ne "") {
-# 	warn "Here $item\n";
 	    $item_str .=  XMLout($item, "RootName" => "item",
 				 'NoIndent' => 1,
 		);
@@ -317,173 +252,34 @@ sub identify_sections {
 
     my @text = split /\n/, $text;
 
-#     warn "Size: " . scalar(@text);
-
-     map {$_ .= "\n"} @text;
-
-#     for($i=0;$i < scalar(@text); $i++) {
-# 	$text[$i] .= "\n";
-#     }
-
+    map {$_ .= "\n"} @text;
     my @text_with_sections;
     my $section_nb = 0;
     $i = 0;
 
-#       warn ">" . $text[$i];
-#     do {
-#	if ($text[$i] !~ /^\s*$/o) {
     &new_section(\$section_nb, \@text_with_sections, $text[$i]);
-#     warn "==>($section_nb)" . $text_with_sections[$section_nb]->{"content"};
-#	}
     $i++;
     do {
-#       warn "->" . $text[$i];
 	&add_in_section($section_nb, \@text_with_sections, $text[$i]);
-#  	warn "==>($section_nb)" . $text_with_sections[$section_nb]->{"content"};
 	$i++;
     } while($text[$i] =~ /^\s*\n$/);
-#    $i--;
     $section_nb++;
     for(;$i <= $#text; $i++) {
-#  	warn "i: $i\n";	
-#   	warn "-->" . $text[$i];
-
 	if (($text[$i] =~ /^\s*[^a-z\d]+:/o) || ($text[$i] =~ /^\s*[^a-z\d][^:]+:/o) || (index($text[$i], "******") > -1)){
 	    &new_section(\$section_nb, \@text_with_sections, $text[$i]);
-#  	    warn "==>($section_nb)" . $text_with_sections[$section_nb]->{"content"};
 	    next;
 	}
-# 	if (($text[$i] =~ /^\s*[^a-z\d\(]+/o) && ($text[$i - 1] !~ /[a-z,]\s*$/o)){
-# 	    &new_section(\$section_nb, \@text_with_sections, $text[$i]);
-# 	    next;
-# 	}
 	&add_in_section($section_nb, \@text_with_sections, $text[$i]);
-#  	warn "==>($section_nb)" . $text_with_sections[$section_nb]->{"content"};
     }
     return(@text_with_sections);
 }
 
-
-# sub identify_listitems {
-#     my ($section, $section_nb_ref) = @_;
-#     my @text_with_sections_and_items;
-
-#     my $item_regex = '^\d+\.\s+';
-
-# #      warn "->$section";
-
-#     my @listSection = (
-# 	"DISCHARGE MEDICATIONS",
-# 	"MEDICATIONS ON ADMISSION",
-# 	"ADMISSION MEDICATIONS",
-# 	"ADDENDUM TO MEDICATIONS ON DISCHARGE",
-# 	"MEDICATION AT TIME OF DISCHARGE",
-# # 	"",
-# # 	"",
-# # 	"",
-# # 	"",
-# 	);
-
-
-# }
-
-# sub add_in_section {
-#     my ($section_nb, $ref_text_with_sections, $text) = @_;
-#     # "\n" . 
-
-#     $ref_text_with_sections->[$section_nb]->{"content"} .= $text;
-# }
-
-# sub new_item {
-#     my ($ref_item_nb, $ref_text_with_items, $text) = @_;
-    
-#     $$ref_item_nb++;
-#     $ref_text_with_items->[$$ref_item_nb] = $text;
-
-# }
-
-# sub add_in_item {
-#     my ($item_nb, $ref_text_with_items, $text) = @_;
-    
-# # "\n" . 
-#     $ref_text_with_items->[$item_nb] .= $text;
-# }
-
-# sub print_list {
-#     my ($list_ref) = @_;
-#     my $item;
-
-#     print "<section><list>";
-#     foreach $item (@{$list_ref}) {
-# 	print XMLout($item, "RootName" => "item",
-# 		     'NoIndent' => 1,
-# 	    );
-#     }
-#     print "</list></section>";
-
-    
-# }
-
-
-# sub identify_sections {
-#     my ($text) = @_;
-
-#     my @text = split /\n/, $text;
-
-# #     warn "Size: " . scalar(@text);
-
-#      map {$_ .= "\n"} @text;
-
-# #     for($i=0;$i < scalar(@text); $i++) {
-# # 	$text[$i] .= "\n";
-# #     }
-
-#     my @text_with_sections;
-#     my $section_nb = 0;
-#     $i = 0;
-
-# #      warn "-->" . $text[$i];
-# #     do {
-# #	if ($text[$i] !~ /^\s*$/o) {
-#     &new_section(\$section_nb, \@text_with_sections, $text[$i]);
-# #     warn "==>($section_nb)" . $text_with_sections[$section_nb]->{"content"};
-# #	}
-#     $i++;
-#     do {
-# 	&add_in_section($section_nb, \@text_with_sections, $text[$i]);
-# #  	warn "==>($section_nb)" . $text_with_sections[$section_nb]->{"content"};
-# 	$i++;
-#     } while($text[$i] =~ /^\s*\n$/);
-# #    $i--;
-#     $section_nb++;
-#     for(;$i <= $#text; $i++) {
-# # 	warn "i: $i\n";	
-# #  	warn "-->" . $text[$i];
-
-# 	if (($text[$i] =~ /^\s*[^a-z\d]+:/o) || ($text[$i] =~ /^\s*[^a-z\d][^:]+:/o) || (index($text[$i], "******") > -1)){
-# 	    &new_section(\$section_nb, \@text_with_sections, $text[$i]);
-# #  	    warn "==>($section_nb)" . $text_with_sections[$section_nb]->{"content"};
-# 	    next;
-# 	}
-# # 	if (($text[$i] =~ /^\s*[^a-z\d\(]+/o) && ($text[$i - 1] !~ /[a-z,]\s*$/o)){
-# # 	    &new_section(\$section_nb, \@text_with_sections, $text[$i]);
-# # 	    next;
-# # 	}
-# 	&add_in_section($section_nb, \@text_with_sections, $text[$i]);
-# #  	warn "==>($section_nb)" . $text_with_sections[$section_nb]->{"content"};
-#     }
-#     return(@text_with_sections);
-# }
-
-
 sub identify_listitems {
     my ($section, $section_nb_ref) = @_;
     my @text_with_sections_and_items;
 
     my $item_regex = '^\b\d+\.\s+';
 
-#          warn "-> () $section";
-
     my @listSection = (
 	"DISCHARGE MEDICATIONS",
 	"DISCHARGE MEDS",
@@ -547,17 +343,13 @@ sub identify_listitems {
 	$sectionType = "list";
 	
   	&new_item(\$item_nb, \@items, ""); 
-#      	&add_in_section($$section_nb_ref, \@text_with_sections_and_items, \@items);
 	my %tmp2 = ("content" => \@items,
 		     "sectionType" => "list",
 	);
 
 	push @sections, \%tmp2;
 	}
-#	$text_with_sections_and_items[$$section_nb_ref]->{"title"} = $listSection[$k];
-#  	&add_in_section($section_nb_ref, \@text_with_sections_and_items, \@items);
     } else {
-
 	if ($section =~ /^(\s*([A-Z][^:\d\+\.]+):\s*)(\d+\.\s+)/o) {	
 	    my @sections;
 	    my $start_listsection = $1;
@@ -572,7 +364,6 @@ sub identify_listitems {
 	    $text_with_sections_and_items[$$section_nb_ref]->{"title"} = $start_listsection_title;
 
 	    $sectionType = "list";
-#	    warn "--> ".  $start_listsection . "\n";
 
 	    &new_item(\$item_nb, \@items, ""); 
 #      	&add_in_section($$section_nb_ref, \@text_with_sections_and_items, \@items);
@@ -582,24 +373,18 @@ sub identify_listitems {
 
 	    push @sections, \%tmp2;
 	}
-# 	warn "$section: it is not a list\n";
     }
-#      warn "type of section: $sectionType\n";
 
     @text_section = split /\n/, $section;
 
     map{$_ .= "\n"} @text_section;
 
     for($j=0;$j<= $#text_section;$j++) {
-#    	warn "=====> " . $text_section[$j]  . "\n";
 	if ($text_section[$j] =~ /$item_regex/) {
-#       	    warn "match item $item_nb $& $sectionType\n";
 	    if (($item_nb == -1) && ($sectionType ne "list")) {
 		my $title;
 		my @sections;
-#   		warn "==>" . $text_section[$j] . "\n";
 		if ($text_section[$j] =~ /^(\s*([A-Z][^:\d\+\.]+):\s*)/o) {
-#  		    warn "TITLE = $1 ($&)\n";
 		    $title = $2;
 		    $sectionType = "list";
 		    my %tmp = ("content" => $1,
@@ -619,29 +404,21 @@ sub identify_listitems {
 		    push @sections, \%tmp2;
 		    
 		} else {
-#		    warn "Pass here\n";
 		    &add_in_section($$section_nb_ref, \@text_with_sections_and_items, $text_section[$j]);
 		}
-
-# 		&new_section($section_nb_ref, \@text_with_sections_and_items, \@items, "list");
-# 		$text_with_sections_and_items->{"title"} = $title;
 	    } else {
 		&new_item(\$item_nb, \@items, $text_section[$j]); 
 	    }
 	    next;
 	}
 	if ($item_nb == -1) {
-#  	    warn "add in item -1\n";
 	    &add_in_section($$section_nb_ref, \@text_with_sections_and_items, $text_section[$j]);
-#  	    warn "==>($$section_nb_ref)" . $text_with_sections_and_items[$$section_nb_ref]->{"content"};
 	} else {
-#  	    warn "add in item\n";
 	    &add_in_item($item_nb, \@items, $text_section[$j]);
 	}
     }
     if (defined $section_tail) {
 	&add_in_section($$section_nb_ref, \@text_with_sections_and_items, $section_tail);
-# 	    warn "==>($$section_nb_ref)" . $text_with_sections_and_items[$$section_nb_ref]->{"content"};
     }
     $$section_nb_ref++;
     return(@text_with_sections_and_items);
@@ -649,12 +426,10 @@ sub identify_listitems {
 
 sub identify_title  {
     my ($text, $titles_ref) = @_;
-# 	print STDERR "==>$text\n";
     my $title = "";
 
     if (($text ne "") && (ref($text) ne "ARRAY")) {
 	$text =~ s/^\n+//o;
-
 	if ($text =~ /^\**([A-Z][^:\d\+\.]+):/o) {
 	    $title = $1;
 	    if (length($title) != 1) {
@@ -668,16 +443,6 @@ sub identify_title  {
 		}
 	    }
 	}
-
-
-
-# 	    if (|([A-Z+\- ]+)[:\.]
-# 	}
-# 	    if ($text =~ /(^([A-Z\-]{2,}(\s[A-Z\-]+)+)\b)/) {
-# 		$title = $1;
-# 		print STDERR ">>>title2 = $title\n";
-# 	    }
-# 	}
     }
     return($title);
 }
@@ -701,7 +466,6 @@ sub identify_title_from_known_titles {
 	    if (index($text, $known_title, 1) != -1) {
 		if ($text =~ s/(\b)(\Q$known_title\E\b)/\1<SECTION>\2<TITLE>\2/) {
 		    $exists_title++;
-# 		    print STDERR "found $known_title in $text\n\n";
 		}
 	    }
 	}
@@ -716,15 +480,11 @@ sub identify_title_from_known_titles {
 		$end_title_pos = index($sections_text[$i], "<TITLE>",0);
 		$title = substr($sections_text[$i], 0, $end_title_pos);
 		$new_text = substr($sections_text[$i], $end_title_pos+7);
-
-# 		print STDERR "title=$title\n";
-# 		print STDERR "content=$new_text\n";
 		$sections[$i] = {"content" => $new_text,
 				 "title" => $title,
 			     };
 	
 	    }
-	    
 	}
     }
     return(@sections);
@@ -745,28 +505,25 @@ sub cleanOUTPUT {
     $str =~ s/\x{0009}/        /og;
     $str =~ s/[\x{0000}-\x{001F}]//og;
     chomp $str;
-#
+
     $str =~ s/[\x{2000}-\x{200B}]/ /go;
     $str =~ s/[\x{2018}-\x{201B}]/\'/go;
     $str =~ s/[\x{201C}-\x{201F}]/\"/go;
     $str =~ s/[\x{2010}-\x{2015}]/\-/go;
     $str =~ s/[\x{2010}-\x{2015}]/\-/go;
     $str =~ s/[\x{2010}-\x{2015}]/\-/go;
-#
+
 # PRIVATE CODES -> removed
     $str =~ s/\x{F09F} /\n\n- /go;
     $str =~ s/[\x{E000}-\x{F8FF}]//go;
-#
     $str =~ s/\x{FFFD}//go;
-#
     $str =~ s/\x{2024}/./go;
     $str =~ s/\x{2025}/../go;
     $str =~ s/\x{2026}/.../go;
-#
-#
+
+
 # SPECIAL TREATMENT TO ADD
     $str =~ s/\x{2022} ?\n+/\- /go;
-#
     $str =~ s/\x{fb00}/ff/go;
     $str =~ s/\x{fb01}/fi/go;
     $str =~ s/\x{fb02}/fl/go;
@@ -774,24 +531,18 @@ sub cleanOUTPUT {
     $str =~ s/\x{fb04}/ffl/go;
     $str =~ s/\x{fb05}/ft/go;
     $str =~ s/\x{fb06}/st/go;
-#
     $str =~ s/\n- \n+- /\n- /go;
-
-# {
-# }
-
     return($str);
 }
 
-
-
 ########################################################################
 
+=encoding utf8
+
 =head1 NAME
 
 Txt2Ogmios.pl - Script for converting text file in XML Ogmios file
 
-
 =head1 SYNOPSIS
 
 Txt2Ogmios.pl [option] --file <filename> --lang <language> --docId <documentId>
