@@ -1074,7 +1074,7 @@ sub _parseCanonicalDocument {
 	    # if ($section =~ /([^<]*)<[^>]+>/os) {
 	    #     $end_position += length($1);
 	    # }
-	    while($section =~ s/([^<]*)<[^>]+>//cos) {
+	    while($section =~ s/([^<]*)<[^>]+>//os) {
 		$end_position += length($1);
 	    }
 	    # warn "\t" . $end_position . "(b)\n";
@@ -1697,7 +1697,7 @@ __END__
 
 =head1 NAME
 
-Lingua::Ogmios::??? - Perl extension for ???.
+Lingua::Ogmios::Annotations - Perl extension for representing the annotations in the Ogmios platform.
 
 =head1 SYNOPSIS
 
