@@ -191,25 +191,29 @@ sub existsElementFromReference {
 }
 
 sub printIndex {
-    my ($self, $indexfield) = @_;
+    my ($self, $indexfield, $fh) = @_;
+    if (!defined $fh) {
+	$fh = \*STDERR
+    }
 
     my $elt;
     my $idx;
     my $item;
 
     foreach $idx (keys %{$self->getIndex($indexfield)}) {
-	print STDERR "$idx:\n";
-	print STDERR "\t" . $self->getIndex($indexfield)->{$idx} . "\n";
+	print $fh "$idx:\n";
+	print $fh "\t" . $self->getIndex($indexfield)->{$idx} . "\n";
 	if (ref($self->getIndex($indexfield)->{$idx}) eq "ARRAY") {
 	    foreach $item (@{$self->getIndex($indexfield)->{$idx}}) {
-		print STDERR "\t (" . ref($item) . ") " . $item->getId . "\n";
-# 		print STDERR "\t (" . ref($item) . ") " . $item->_getField($indexfield) . " : " . $item->getForm . "\n";
+		print $fh "\t (" . ref($item) . ") " . $item->getId . "\n";
+# 		print $fh "\t (" . ref($item) . ") " . $item->_getField($indexfield) . " : " . $item->getForm . "\n";
 	    }
 	} else {
-		print STDERR "\t (" . ref($item) . ") " . $self->getIndex($indexfield)->{$idx}->getId . "\n";
-# 		print STDERR "\t (" . ref($item) . ") " . $self->getIndex($indexfield)->{$idx}->_getField($indexfield) . " : " . $item->getForm . "\n";
+		print $fh "\t (" . ref($item) . ") " . $self->getIndex($indexfield)->{$idx}->getId . "\n";
+# 		print $fh "\t (" . ref($item) . ") " . $self->getIndex($indexfield)->{$idx}->_getField($indexfield) . " : " . $item->getForm . "\n";
 	}
     }
+    return(0);
 }
 
 sub getIndex {
@@ -914,6 +918,8 @@ sub getElementByStartEndTokens {
 	return(undef);
     }
 }
+
+
 sub existsElementByStartEndTokens {
     my ($self, $start_token, $end_token) = @_;
 
@@ -930,6 +936,21 @@ sub existsElementByStartEndTokens {
     return(scalar(@terms) > 0);
 }
 
+sub getElementsByStartToken {
+    my ($self, $start_token) = @_;
+
+    my $term;
+    my @terms;
+
+    # warn "$start_token: " . $start_token->getId . "\n";
+    foreach $term (@{$self->getElementByToken($start_token)}) {
+	# warn "$term\n";
+	if ($term->start_token->equals($start_token)) {
+	    push @terms, $term;
+	}
+    }
+    return(\@terms);
+}
 
 1;
 
@@ -937,7 +958,7 @@ __END__
 
 =head1 NAME
 
-Lingua::Ogmios::Annotations::??? - Perl extension for ???.
+Lingua::Ogmios::Annotations::Level - Perl extension for the level of annotations
 
 =head1 SYNOPSIS
 
