@@ -46,7 +46,7 @@ sub setConfigData {
 
     my $conf = new Config::General('-ConfigFile' => $rcfile,
  				   '-InterPolateVars' => 1,
- 				   '-InterPolateEnv' => 1
+ 				   '-InterPolateEnv' => 1,
 	);
     
     my %config = $conf->getall;
@@ -151,6 +151,8 @@ sub OgmiosOutStream {
 
     if (defined $out_stream) {
 	$self->getConfigData->{'OUT_STREAM'} = $out_stream;
+    } else {
+	$self->getConfigData->{'OUT_STREAM'} = \*STDERR
     }
     return(eval($self->getConfigData->{'OUT_STREAM'}));
 }
@@ -906,7 +908,7 @@ sub getOrderedWrappers {
     return(@OrderedWrappers);
 }
 
-sub _printLinguisticAnnotation {
+sub _printLinguisticAnnotationFull {
     my ($self,$lang) = @_;
 
     my $processing;
@@ -925,7 +927,7 @@ sub _printLinguisticAnnotation {
     }
 }
 
-sub _printLinguisticAnnotationFull {
+sub _printLinguisticAnnotation {
     my ($self,$lang) = @_;
 
     my $processing;
@@ -1085,7 +1087,7 @@ __END__
 
 =head1 NAME
 
-Lingua::Ogmios::??? - Perl extension for ???.
+Lingua::Ogmios::Config - Perl extension for the configuration of the Ogmios NLP platform
 
 =head1 SYNOPSIS
 
