@@ -505,7 +505,7 @@ __END__
 
 =head1 NAME
 
-Lingua::Ogmios::??? - Perl extension for ???.
+Lingua::Ogmios::DocumentRecord - Perl extension for managing a document in the Ogmios platform
 
 =head1 SYNOPSIS
 
