@@ -84,7 +84,9 @@ sub new {
 	}
     } else {
 	$SentenceSeg->{'sentenceSeparatorCharList'}->{"FR"} = "?.!";
+	$SentenceSeg->{'lang_methods'}->{'FR'} = "en,fr,de,es,it";
 	$SentenceSeg->{'sentenceSeparatorCharList'}->{"EN"} = "?.!";	
+	$SentenceSeg->{'lang_methods'}->{'EN'} = "en,fr,de,es,it";
     }
 #     $SentenceSeg->_input_filename($tmpfile_prefix . ".SentSeg.in");
 #     $SentenceSeg->_output_filename($tmpfile_prefix . ".SentSeg.out");
