@@ -40,6 +40,12 @@ sub new {
 	    if ($lang =~ /language=([\w]+)/io) {
 		$lang2 = $1;
 		# $YaTeA->_setOption($lang2, "ONLY_SYNTACTIC_RELATIONS", "only_synt_rel", 0);
+		$YaTeA->_setOption($lang2,"TAGGEDSENTFIELDS", "tagged_sent_fields", "IF:POSTAG:LM:ID:DOCID:SEMTAG");
+		$YaTeA->_setOption($lang2,"TAGGEDSENTSEPINFOS", "tagged_sent_sep_infos", "/");
+		$YaTeA->_setOption($lang2,"TAGGEDSENTSEPTERMCOMPONENTS", "tagged_sent_sep_term_components", " ");
+		$YaTeA->_setOption($lang2,"TAGGEDSENTSEPWORDS", "tagged_sent_sep_words", " ");
+		$YaTeA->_setOption($lang2,"TAGGEDSENTSEPSENTENCES", "tagged_sent_sep_sentences", "\n");
+		$YaTeA->_setOption($lang2,"TAGGEDSENTSEPSECTIONS", "tagged_sent_sep_sections", "");
 	    }
 	    $YaTeA->_setGeneralOption("PRINTOUTPUTSECTION", "print_output_section", 0);
 	}
@@ -742,7 +748,21 @@ sub run {
 		if ($self->{print_output_section}) {print $fh "==== TAGGEDSENT ====\n";}
 		warn "print Tagged Sentence output\n";
 		$self->_outputParsing;
-		$self->_makeTaggedSentences({}, $fh, "/", " ");
+		my $lang = $self->_documentSet->[0]->getAnnotations->getLanguage;
+		my @f = split /:/, $self->{"tagged_sent_fields"}->{$lang};
+		my $rank = 1;
+		my %fields = map { $_ => $rank++; } @f;
+		$self->_makeTaggedSentences({}, $fh, $self->{"tagged_sent_sep_infos"}->{$lang}, $self->{"tagged_sent_sep_words"}->{$lang}, $self->{"tagged_sent_sep_sentences"}->{$lang}, $self->{"tagged_sent_sep_sections"}->{$lang}, $self->{"tagged_sent_sep_term_components"}->{$lang}, \%fields);
+	    }
+	    if ($output eq "TAGGEDSENTREC") {
+		if ($self->{print_output_section}) {print $fh "==== TAGGEDSENTREC ====\n";}
+		warn "print Tagged Sentence Recursive output\n";
+		$self->_outputParsing;
+		my $lang = $self->_documentSet->[0]->getAnnotations->getLanguage;
+		my @f = split /:/, $self->{"tagged_sent_fields"}->{$lang};
+		my $rank = 1;
+		my %fields = map { $_ => $rank++; } @f;
+		$self->_makeTaggedSentencesRec({}, $fh, $self->{"tagged_sent_sep_infos"}->{$lang}, $self->{"tagged_sent_sep_words"}->{$lang}, $self->{"tagged_sent_sep_sentences"}->{$lang}, $self->{"tagged_sent_sep_sections"}->{$lang}, $self->{"tagged_sent_sep_term_components"}->{$lang}, \%fields);
 	    }
 	    if ($output eq "CRFINPUT") {
 		warn "print Tagged Sentence output (CRFINPUT)\n";
